#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

from cthulhu import plugin

import gi
gi.require_version('Peas', '1.0')
from gi.repository import GObject
from gi.repository import Peas
from cthulhu import cthulhuVersion

class DisplayVersion(GObject.Object, Peas.Activatable, plugin.Plugin):
    __gtype_name__ = 'displayversion'

    object = GObject.Property(type=GObject.Object)
    
    def __init__(self):
        plugin.Plugin.__init__(self)
        self._api = None
    
    def do_activate(self):
        self._api = self.object
        self.registerGestureByString(
            self.speakText, 
            _(f'Cthulhu screen reader version {cthulhuVersion.version}-{cthulhuVersion.codeName}'), 
            'kb:cthulhu+x'
        )
    
    def do_deactivate(self):
        self._api = None
    
    def speakText(self, script=None, inputEvent=None):
        if not self._api:
            return False
        self._api.app.getDynamicApiManager().getAPI('CthulhuState').activeScript.presentMessage(
            f'Cthulhu screen reader version {cthulhuVersion.version}-{cthulhuVersion.codeName}',
            resetStyles=False
        )
        return True
