#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

"""Test of ARIA slider presentation."""

from macaroon.playback import *
import utils

sequence = MacroSequence()

#sequence.append(WaitForDocLoad())
sequence.append(PauseAction(5000))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Tab"))
sequence.append(utils.AssertPresentationAction(
    "1. tab to slider",
    ["BRAILLE LINE:  'My slider 10% horizontal slider'",
     "     VISIBLE:  'My slider 10% horizontal slider', cursor=1",
     "BRAILLE LINE:  'Focus mode'",
     "     VISIBLE:  'Focus mode', cursor=0",
     "SPEECH OUTPUT: 'My slider horizontal slider 10%'",
     "SPEECH OUTPUT: 'Focus mode' voice=system"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_Enter"))
sequence.append(utils.AssertPresentationAction(
    "2. basic whereAmI",
    ["BRAILLE LINE:  'My slider 10% horizontal slider'",
     "     VISIBLE:  'My slider 10% horizontal slider', cursor=1",
     "BRAILLE LINE:  'My slider 10% horizontal slider'",
     "     VISIBLE:  'My slider 10% horizontal slider', cursor=1",
     "SPEECH OUTPUT: 'My slider horizontal slider 10% 10 percent.'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Right"))
sequence.append(utils.AssertPresentationAction(
    "3. move slider right",
    ["BRAILLE LINE:  'My slider $15.00 horizontal slider'",
     "     VISIBLE:  'My slider $15.00 horizontal slid', cursor=1",
     "SPEECH OUTPUT: '$15.00'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Right"))
sequence.append(utils.AssertPresentationAction(
    "4. move slider right",
    ["BRAILLE LINE:  'My slider $20.00 horizontal slider'",
     "     VISIBLE:  'My slider $20.00 horizontal slid', cursor=1",
     "SPEECH OUTPUT: '$20.00'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Left"))
sequence.append(utils.AssertPresentationAction(
    "5. move slider left",
    ["BRAILLE LINE:  'My slider $15.00 horizontal slider'",
     "     VISIBLE:  'My slider $15.00 horizontal slid', cursor=1",
     "SPEECH OUTPUT: '$15.00'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("End"))
sequence.append(utils.AssertPresentationAction(
    "6. move slider end",
    ["BRAILLE LINE:  'My slider $100.00 horizontal slider'",
     "     VISIBLE:  'My slider $100.00 horizontal sli', cursor=1",
     "SPEECH OUTPUT: '$100.00'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Home"))
sequence.append(utils.AssertPresentationAction(
    "7. move slider home",
    ["BRAILLE LINE:  'My slider $0.00 horizontal slider'",
     "     VISIBLE:  'My slider $0.00 horizontal slide', cursor=1",
     "SPEECH OUTPUT: '$0.00'"]))

sequence.append(utils.AssertionSummaryAction())
sequence.start()
