#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

"""Test of checkbox output."""

from macaroon.playback import *

sequence = MacroSequence()
import utils

sequence.append(KeyComboAction("<Control>f"))
sequence.append(TypeAction("Paned Widgets"))
sequence.append(KeyComboAction("Return"))
sequence.append(KeyComboAction("Return"))
sequence.append(PauseAction(3000))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Tab"))
sequence.append(utils.AssertPresentationAction(
    "1. Tab to first checkbox",
    ["BRAILLE LINE:  'gtk3-demo application Paned Widgets frame Horizontal panel < > Resize check box'",
     "     VISIBLE:  '< > Resize check box', cursor=1",
     "SPEECH OUTPUT: 'Horizontal panel.'",
     "SPEECH OUTPUT: 'Resize check box not checked.'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_Enter"))
sequence.append(utils.AssertPresentationAction(
    "2. Where Am I",
    ["BRAILLE LINE:  'gtk3-demo application Paned Widgets frame Horizontal panel < > Resize check box'",
     "     VISIBLE:  '< > Resize check box', cursor=1",
     "SPEECH OUTPUT: 'Horizontal Resize check box not checked.'",
     "SPEECH OUTPUT: 'Alt+R'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(TypeAction(" "))
sequence.append(utils.AssertPresentationAction(
    "3. Toggle its state",
    ["BRAILLE LINE:  'gtk3-demo application Paned Widgets frame Horizontal panel <x> Resize check box'",
     "     VISIBLE:  '<x> Resize check box', cursor=1",
     "SPEECH OUTPUT: 'checked'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_Enter"))
sequence.append(utils.AssertPresentationAction(
    "4. Where Am I",
    ["BRAILLE LINE:  'gtk3-demo application Paned Widgets frame Horizontal panel <x> Resize check box'",
     "     VISIBLE:  '<x> Resize check box', cursor=1",
     "SPEECH OUTPUT: 'Horizontal Resize check box checked.'",
     "SPEECH OUTPUT: 'Alt+R'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(TypeAction(" "))
sequence.append(utils.AssertPresentationAction(
    "5. Toggle its state back",
    ["BRAILLE LINE:  'gtk3-demo application Paned Widgets frame Horizontal panel < > Resize check box'",
     "     VISIBLE:  '< > Resize check box', cursor=1",
     "SPEECH OUTPUT: 'not checked'"]))

sequence.append(KeyComboAction("Tab"))
sequence.append(KeyComboAction("Tab"))
sequence.append(KeyComboAction("Tab"))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Tab"))
sequence.append(utils.AssertPresentationAction(
    "6. Tab to first checkbox in next panel",
    ["BRAILLE LINE:  'gtk3-demo application Paned Widgets frame Vertical panel < > Resize check box'",
     "     VISIBLE:  '< > Resize check box', cursor=1",
     "SPEECH OUTPUT: 'Vertical panel.'",
     "SPEECH OUTPUT: 'Resize check box not checked.'"]))

sequence.append(KeyComboAction("<Alt>F4"))

sequence.append(utils.AssertionSummaryAction())
sequence.start()
