#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

"""Test to verify spell checking support."""

from macaroon.playback import *
import utils

sequence = MacroSequence()

sequence.append(TypeAction("The quuuiick brown fox"))
sequence.append(KeyComboAction("Return"))
sequence.append(TypeAction("jumps overr the lazy dog"))
sequence.append(KeyComboAction("Return"))
sequence.append(KeyComboAction("<Control>Home"))
sequence.append(PauseAction(3000))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("F7"))
sequence.append(PauseAction(3000))
sequence.append(utils.AssertPresentationAction(
    "1. Enter F7 to bring up the spell checking dialog",
    ["SPEECH OUTPUT: 'Spelling: English (USA) frame'",
     "SPEECH OUTPUT: 'Misspelled word: quuuiick'",
     "SPEECH OUTPUT: 'q'",
     "SPEECH OUTPUT: 'u'",
     "SPEECH OUTPUT: 'u'",
     "SPEECH OUTPUT: 'u'",
     "SPEECH OUTPUT: 'i'",
     "SPEECH OUTPUT: 'i'",
     "SPEECH OUTPUT: 'c'",
     "SPEECH OUTPUT: 'k'",
     "SPEECH OUTPUT: 'Suggestions quick'",
     "SPEECH OUTPUT: 'q'",
     "SPEECH OUTPUT: 'u'",
     "SPEECH OUTPUT: 'i'",
     "SPEECH OUTPUT: 'c'",
     "SPEECH OUTPUT: 'k'",
     "SPEECH OUTPUT: 'Context is The quuuiick brown fox'",
     "SPEECH OUTPUT: 'Spelling: English (USA) dialog'",
     "SPEECH OUTPUT: 'Correct push button'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("<Alt>I"))
sequence.append(PauseAction(3000))
sequence.append(utils.AssertPresentationAction(
    "2. Alt I to ignore the first error and present the next",
    ["SPEECH OUTPUT: 'Suggestions overt'",
     "SPEECH OUTPUT: 'o'",
     "SPEECH OUTPUT: 'v'",
     "SPEECH OUTPUT: 'e'",
     "SPEECH OUTPUT: 'r'",
     "SPEECH OUTPUT: 't'"]))

sequence.append(KeyComboAction("<Alt>F4"))
sequence.append(utils.AssertionSummaryAction())
sequence.start()
